/*
 * Driver include for the RICOH5B Tuner chip.
 *
 * Copyright 2015, 2016 SONY Corporation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef  _STDRV_IF_DEFINE_H
#define  _STDRV_IF_DEFINE_H

/******************************************************************************/
/* include file                                                               */
/******************************************************************************/
/******************************************************************************/
/* object generation control and special settings                             */
/******************************************************************************/
/******************************************************************************/
/* symbolic constant definition                                               */
/******************************************************************************/

/* unknown frequecny */
#define STDRV_FREQ_UNKNOWN        0xFFFF

/*! @enum STDRV_POWER_STATUS
 *        Power Status
 */
typedef enum
{
  STDRV_POWER_OFF    = 0,  //!< :Power OFF
  STDRV_POWER_ON     = 1   //!< :Power ON
} STDRV_POWER_STATUS;

/*! @enum STDRV_BAND_STATUS
 *        TUNER BAND
 */
typedef enum
{
  STDRV_BAND_IDLE    = 0,  //!< :Default State (BAND is not selected)
  STDRV_BAND_FM      = 1,  //!< :FM
  STDRV_BAND_AM      = 2   //!< :AM
} STDRV_BAND_STATUS;

/*! @enum STDRV_STATION_STATUS
 *        station detected / undetect in each band
 */
typedef enum
{
  STDRV_STATION_UNDETECT  = 0,    //!< :Station is undetect
  STDRV_STATION_DETECTED  = 1,    //!< :Station is detected
  STDRV_STATION_UNKNOWN   = 0xFF  //!< :unknown
} STDRV_STATION_STATUS;

/*! @enum STDRV_AUDIO_STATUS
 *        audio status in each band
 */
typedef enum
{
  STDRV_AUDIO_MONO     = 0,    //!< :Mono Broadcasting
  STDRV_AUDIO_STEREO   = 1,    //!< :Stereo Broadcasting
  STDRV_AUDIO_UNKNOWN  = 0xFF  //!< :unknown
} STDRV_AUDIO_STATUS;

/*! @enum STDRV_MONO_MODE
 *        force mono output mode
 */
typedef enum
{
  STDRV_MONO_OFF      = 0,    //!< :Force mono output is OFF
  STDRV_MONO_ON       = 1,    //!< :Force mono output is ON
  STDRV_MONO_UNKNOWN  = 0xFF  //!< :unknown
} STDRV_MONO_MODE;

/*! @enum STDRV_VOLUME
 *        audio output volume
 */
typedef enum
{
  STDRV_VOLUME_0DB        = 0,    //!< :0dB
  STDRV_VOLUME_MINUS_3DB  = 1,    //!< :-3dB
  STDRV_VOLUME_MINUS_4DB  = 2,    //!< :-4dB
  STDRV_VOLUME_MINUS_5DB  = 3,    //!< :-5dB
  STDRV_VOLUME_UNKNOWN    = 0xFF  //!< :unknown
} STDRV_VOLUME;

/*! @enum STDRV_IMMUNITY
 *        immunity measure ENABLE / DISABLE
 */
typedef enum
{
  STDRV_IMMUNITY_DISABLE    = 0,  //!< :Immunity Measure is Disable
  STDRV_IMMUNITY_ENABLE     = 1,  //!< :Immunity Measure is Enable
  STDRV_IMMUNITY_ENABLE_KR  = 2,  //!< :Immunity Measure is Enable for KOREA
  STDRV_IMMUNITY_UNKNOWN    = 0xFF  //!< :unknown
} STDRV_IMMUNITY;

#endif  /* _STDRV_IF_DEFINE_H */

/* end of stdrv_if_define.h */
